==> haskell-validation-selective-0.2.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-EHZerG6Vag1H0iQAMvpAap
key:                  validation-selective-0.2.0.0-EHZerG6Vag1H0iQAMvpAap
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  99c1cd49c676840bffc2ad02b7a7312b
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.0.2/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-EHZerG6Vag1H0iQAMvpAap
depends:
    base-4.15.1.0 deepseq-1.4.5.0 selective-0.6-7SR4ngnflsbHvexJRCpKBx

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validation-selective-0.2.0.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validation-selective.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-BzJNNJzE3TfXLSVxdTO2l
key:                  validation-selective-0.2.0.0-BzJNNJzE3TfXLSVxdTO2l
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  a9438057816ba060a9636f040bbabecc
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-BzJNNJzE3TfXLSVxdTO2l
depends:
    base-4.16.4.0 deepseq-1.4.6.1 selective-0.6-K3ysBvjCt6311S7DgtpmkV

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
